summaryrefslogtreecommitdiff
path: root/yaksh
diff options
context:
space:
mode:
Diffstat (limited to 'yaksh')
-rw-r--r--yaksh/demo_templates/demo_settings.py179
-rw-r--r--yaksh/demo_templates/demo_urls.py16
-rw-r--r--yaksh/models.py16
-rw-r--r--yaksh/scripts/cli.py173
-rw-r--r--yaksh/templates/yaksh/grade_user.html4
-rw-r--r--yaksh/templates/yaksh/view_answerpaper.html2
-rw-r--r--yaksh/test_models.py21
-rw-r--r--yaksh/test_views.py32
-rw-r--r--yaksh/urls.py13
-rw-r--r--yaksh/views.py37
10 files changed, 72 insertions, 421 deletions
diff --git a/yaksh/demo_templates/demo_settings.py b/yaksh/demo_templates/demo_settings.py
deleted file mode 100644
index 6089be5..0000000
--- a/yaksh/demo_templates/demo_settings.py
+++ /dev/null
@@ -1,179 +0,0 @@
-"""
-Django settings for my_demo project.
-
-For more information on this file, see
-https://docs.djangoproject.com/en/1.6/topics/settings/
-
-For the full list of settings and their values, see
-https://docs.djangoproject.com/en/1.6/ref/settings/
-"""
-
-# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
-import os
-import tempfile
-from yaksh.pipeline.settings import AUTH_PIPELINE
-
-BASE_DIR = os.path.dirname(os.path.dirname(__file__))
-
-# The directory where user data can be saved.
-OUTPUT_DIR = os.path.join(tempfile.gettempdir(), 'output')
-
-# Quick-start development settings - unsuitable for production
-# See https://docs.djangoproject.com/en/1.6/howto/deployment/checklist/
-
-# SECURITY WARNING: keep the secret key used in production secret!
-SECRET_KEY = 'TH!S_!S_@_DUMMY_K3Y'
-
-# SECURITY WARNING: don't run with debug turned on in production!
-DEBUG = True
-
-ALLOWED_HOSTS = []
-
-URL_ROOT = ''
-
-# Application definition
-
-FIXTURE_DIRS = ('{{ fixture_dir }}')
-
-INSTALLED_APPS = (
- 'django.contrib.admin',
- 'django.contrib.auth',
- 'django.contrib.contenttypes',
- 'django.contrib.sessions',
- 'django.contrib.messages',
- 'django.contrib.staticfiles',
- 'yaksh',
- 'taggit',
- 'social.apps.django_app.default',
-)
-
-MIDDLEWARE_CLASSES = (
- 'django.contrib.sessions.middleware.SessionMiddleware',
- 'django.middleware.common.CommonMiddleware',
- 'django.middleware.csrf.CsrfViewMiddleware',
- 'django.contrib.auth.middleware.AuthenticationMiddleware',
- 'django.contrib.messages.middleware.MessageMiddleware',
- 'django.middleware.clickjacking.XFrameOptionsMiddleware',
- 'yaksh.middleware.one_session_per_user.OneSessionPerUserMiddleware',
- 'yaksh.middleware.user_time_zone.TimezoneMiddleware',
- 'social.apps.django_app.middleware.SocialAuthExceptionMiddleware',
-)
-
-ROOT_URLCONF = '{{ root_urlconf }}'
-
-WSGI_APPLICATION = '{{ project_name }}.wsgi.application'
-
-
-# Database
-# https://docs.djangoproject.com/en/1.6/ref/settings/#databases
-
-DATABASES = {
- 'default': {
- 'ENGINE': 'django.db.backends.sqlite3',
- 'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
- }
-}
-
-# Internationalization
-# https://docs.djangoproject.com/en/1.6/topics/i18n/
-
-LANGUAGE_CODE = 'en-us'
-
-TIME_ZONE = 'UTC'
-
-USE_I18N = True
-
-USE_L10N = True
-
-USE_TZ = True
-
-
-# Static files (CSS, JavaScript, Images)
-# https://docs.djangoproject.com/en/1.6/howto/static-files/
-
-STATIC_URL = '/static/'
-
-LOGIN_URL = '/exam/login/'
-
-LOGIN_REDIRECT_URL = '/exam/'
-
-MEDIA_URL = "/data/"
-
-MEDIA_ROOT = os.path.join(BASE_DIR, "yaksh", "data")
-
-SOCIAL_AUTH_LOGIN_ERROR_URL = '/exam/login/'
-
-EMAIL_USE_TLS = False
-
-EMAIL_HOST = 'your_email_host'
-
-EMAIL_PORT = 'your_email_port'
-
-EMAIL_HOST_USER = 'email_host_user'
-
-EMAIL_HOST_PASSWORD = 'email_host_password'
-
-# Set EMAIL_BACKEND to 'django.core.mail.backends.smtp.EmailBackend'
-# in production
-EMAIL_BACKEND = 'django.core.mail.backends.dummy.EmailBackend'
-
-# SENDER_EMAIL, REPLY_EMAIL, PRODUCTION_URL, IS_DEVELOPMENT are used in email
-# verification. Set the variables accordingly to avoid errors in production
-
-# This email id will be used as <from address> for sending emails.
-# For example no_reply@<your_organization>.in can be used.
-SENDER_EMAIL = 'your_email'
-
-# Organisation/Indivudual Name.
-SENDER_NAME = 'your_name'
-
-# This email id will be used by users to send their queries
-# For example queries@<your_organization>.in can be used.
-REPLY_EMAIL = 'your_reply_email'
-
-# This url will be used in email verification to create activation link.
-# Add your hosted url to this variable.
-# For example https://127.0.0.1:8000 or 127.0.0.1:8000
-PRODUCTION_URL = 'your_project_url'
-
-# Set this variable to <False> once the project is in production.
-# If this variable is kept <True> in production, email will not be verified.
-IS_DEVELOPMENT = True
-
-DEFAULT_FROM_EMAIL = EMAIL_HOST_USER
-
-TEMPLATES = [
- {
- 'BACKEND': 'django.template.backends.django.DjangoTemplates',
- 'APP_DIRS': True,
- 'DIRS': ['yaksh/templates'],
- 'OPTIONS': {
- 'context_processors': [
- 'django.contrib.auth.context_processors.auth',
- 'social.apps.django_app.context_processors.backends',
- 'social.apps.django_app.context_processors.login_redirect',
- ],
- 'debug': False,
- }
- },
-]
-
-SOCIAL_AUTH_GOOGLE_OAUTH2_KEY = 'GOOGLE_KEY_PROVIDED'
-SOCIAL_AUTH_GOOGLE_OAUTH2_SECRET = 'GOOGLE_SECRET_PROVIDED'
-
-SOCIAL_AUTH_FACEBOOK_KEY = 'FACEBOOK_KEY_PROVIDED'
-SOCIAL_AUTH_FACEBOOK_SECRET = 'FACEBOOK_SECRET_PROVIDED'
-
-AUTHENTICATION_BACKENDS = (
- 'social.backends.google.GoogleOAuth2',
- 'social.backends.facebook.FacebookOAuth2',
- 'django.contrib.auth.backends.ModelBackend',
-)
-
-SOCIAL_AUTH_PIPELINE = AUTH_PIPELINE
-
-SOCIAL_AUTH_FACEBOOK_SCOPE = ['email']
-SOCIAL_AUTH_FACEBOOK_PROFILE_EXTRA_PARAMS = {
- 'fields': 'id, name, email'
-
-}
diff --git a/yaksh/demo_templates/demo_urls.py b/yaksh/demo_templates/demo_urls.py
deleted file mode 100644
index 5abc121..0000000
--- a/yaksh/demo_templates/demo_urls.py
+++ /dev/null
@@ -1,16 +0,0 @@
-from django.conf.urls import patterns, include, url
-from django.conf import settings
-from django.conf.urls.static import static
-from django.contrib import admin
-admin.autodiscover()
-
-urlpatterns = patterns('',
- # Examples:
- # url(r'^$', 'my_demo.views.home', name='home'),
- # url(r'^blog/', include('blog.urls')),
-
- url(r'^admin/', include(admin.site.urls)),
- url(r'^exam/', include('yaksh.urls', namespace='yaksh', app_name='yaksh')),
- url(r'^', include('social.apps.django_app.urls', namespace='social')),
-)
-urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT) \ No newline at end of file
diff --git a/yaksh/models.py b/yaksh/models.py
index 49a2384..480a111 100644
--- a/yaksh/models.py
+++ b/yaksh/models.py
@@ -94,8 +94,10 @@ MOD_GROUP_NAME = 'moderator'
def get_assignment_dir(instance, filename):
- upload_dir = instance.question_paper.quiz.description.replace(" ", "_")
- return os.sep.join((upload_dir, instance.user.username,
+ folder_name = instance.course.name.replace(" ", "_")
+ sub_folder_name = instance.question_paper.quiz.description.replace(
+ " ", "_")
+ return os.sep.join((folder_name, sub_folder_name, instance.user.username,
str(instance.assignmentQuestion.id),
filename
))
@@ -2234,20 +2236,19 @@ class AnswerPaper(models.Model):
##############################################################################
class AssignmentUploadManager(models.Manager):
- def get_assignments(self, qp, que_id=None, user_id=None):
+ def get_assignments(self, qp, que_id=None, user_id=None, course_id=None):
if que_id and user_id:
assignment_files = AssignmentUpload.objects.filter(
assignmentQuestion_id=que_id, user_id=user_id,
- question_paper=qp
+ question_paper=qp, course_id=course_id
)
file_name = User.objects.get(id=user_id).get_full_name()
else:
assignment_files = AssignmentUpload.objects.filter(
- question_paper=qp
+ question_paper=qp, course_id=course_id
)
-
file_name = "{0}_Assignment_files".format(
- assignment_files[0].question_paper.quiz.description
+ assignment_files[0].course.name
)
return assignment_files, file_name
@@ -2259,6 +2260,7 @@ class AssignmentUpload(models.Model):
assignmentQuestion = models.ForeignKey(Question)
assignmentFile = models.FileField(upload_to=get_assignment_dir)
question_paper = models.ForeignKey(QuestionPaper, blank=True, null=True)
+ course = models.ForeignKey(Course, null=True, blank=True)
objects = AssignmentUploadManager()
diff --git a/yaksh/scripts/cli.py b/yaksh/scripts/cli.py
deleted file mode 100644
index a1a49ee..0000000
--- a/yaksh/scripts/cli.py
+++ /dev/null
@@ -1,173 +0,0 @@
-from __future__ import print_function
-
-import django
-import subprocess
-import contextlib
-import os
-from os import path
-import argparse
-from django.conf import settings
-from django.core import management
-from django.template import Template, Context
-
-CUR_DIR = os.getcwd()
-SCRIPT_DIR = os.path.abspath(os.path.dirname(__file__))
-PARENT_DIR = os.path.abspath(os.path.join(SCRIPT_DIR, os.pardir))
-TEMPLATE_DIR = path.join(PARENT_DIR, 'demo_templates')
-
-settings.configure()
-django.setup()
-
-
-def main():
- # Parse command-line to obtain the arguments and/or options
- # create top-level parser object
- parser = argparse.ArgumentParser(prog="yaksh")
- subparser = parser.add_subparsers(dest="subcommand")
-
- # create parser for the "create_demo" subcommand
- create_demo_parser = subparser.add_parser(
- "create_demo",
- help="Create a new demo Django project"
- )
- create_demo_parser.add_argument(
- "path", type=str,
- default=path.join(CUR_DIR, "yaksh_demo"),
- nargs="?",
- help="Path to the demo Django project (defaults to 'yaksh_demo')"
- )
-
- # create parser for the "run_demo" subcommand
- run_parser = subparser.add_parser(
- "run",
- help="Initialise django server and run the demo project"
- )
- run_parser.add_argument(
- "path", type=str, nargs=1,
- help="full path to the demo yaksh project"
- )
-
- # create parser for the "run_code_server" subcommand
- code_server_parser = subparser.add_parser(
- "run_code_server",
- help="Initialise yaksh code server"
- )
- code_server_parser.add_argument("-P", "--ports", type=int, nargs='+',
- help="code server ports")
-
- args = parser.parse_args()
-
- if args.subcommand == "create_demo":
- pth = path.abspath(args.path)
- name = path.basename(pth)
- create_demo(name, pth)
- elif args.subcommand == "run":
- pth = path.abspath(args.path[0])
- name = path.basename(pth)
- run_demo(name, pth)
- elif args.subcommand == "run_code_server":
- if args.ports:
- run_server(args.ports)
- else:
- run_server()
-
-
-def create_demo(project_name='yaksh_demo', project_dir=CUR_DIR):
- if not path.exists(project_dir):
- os.makedirs(project_dir)
- try:
- management.call_command('startproject', project_name, project_dir)
- print("Demo Django project '{0}' created at '{1}'".format(
- project_name, project_dir)
- )
- except Exception as e:
- print("Error: {0}\nExiting yaksh Installer".format(e))
-
- if project_dir is None:
- top_dir = path.join(os.getcwd(), project_name)
- else:
- top_dir = project_dir
-
- project_path = path.join(top_dir, project_name)
- fixture_dir = path.join(PARENT_DIR, 'fixtures')
- fixture_path = path.join(fixture_dir, 'demo_fixtures.json')
-
- with _chdir(project_path):
- root_urlconf = "{0}.{1}".format(project_name, 'demo_urls')
- settings_template_path = path.join(TEMPLATE_DIR, 'demo_settings.py')
- settings_target_path = path.join(project_path, 'demo_settings.py')
- settings_context = Context({'project_name': project_name,
- 'root_urlconf': root_urlconf,
- 'fixture_dir': fixture_dir})
- urls_template_path = path.join(TEMPLATE_DIR, 'demo_urls.py')
- urls_target_path = path.join(project_path, 'demo_urls.py')
- loaddata_command = ("python ../manage.py loaddata "
- "--settings={0}.demo_settings {1}").format(
- project_name, fixture_path)
-
- # Create demo_settings file
- _render_demo_files(
- settings_template_path, settings_target_path, settings_context
- )
- # Create demo_urls file
- _render_demo_files(urls_template_path, urls_target_path)
- # Create database and load initial data
- command_path = path.join(top_dir, 'manage.py')
- _check_migrations(project_name, command_path)
- _migrate(project_name, command_path)
- subprocess.call(loaddata_command, shell=True)
-
-
-def run_demo(project_name, top_dir):
- with _chdir(top_dir):
- command_path = path.join(top_dir, 'manage.py')
- _check_migrations(project_name, command_path)
- _migrate(project_name, command_path)
- command = ("python manage.py runserver "
- "--settings={0}.demo_settings").format(project_name)
- subprocess.call(command, shell=True)
-
-
-def run_server(args=None):
- try:
- from yaksh import code_server
- code_server.main(args)
- except Exception as e:
- print("Error: {0}\nExiting yaksh code server".format(e))
-
-
-def _check_migrations(project_name, command_path):
- migrations = ("python {0} makemigrations --settings={1}.demo_settings"
- ).format(command_path, project_name)
- subprocess.call(migrations, shell=True)
-
-
-def _migrate(project_name, command_path):
- migrate = ("python {0} migrate --settings={1}.demo_settings"
- ).format(command_path, project_name)
- subprocess.call(migrate, shell=True)
-
-
-def _render_demo_files(template_path, output_path, context=None):
- with open(template_path, 'r') as template_file:
- content = template_file.read()
- if context:
- template = Template(content)
- content = template.render(context)
-
- with open(output_path, 'w') as new_file:
- new_file.write(content)
-
-
-@contextlib.contextmanager
-def _chdir(path):
- starting_directory = os.getcwd()
- try:
- os.chdir(path)
- yield
- finally:
- os.chdir(starting_directory)
-
-
-if __name__ == '__main__':
- main()
diff --git a/yaksh/templates/yaksh/grade_user.html b/yaksh/templates/yaksh/grade_user.html
index 8430e91..2e5a403 100644
--- a/yaksh/templates/yaksh/grade_user.html
+++ b/yaksh/templates/yaksh/grade_user.html
@@ -62,7 +62,7 @@ $(document).ready(function()
{% if has_quiz_assignments %}
-<a href="{{URL_ROOT}}/exam/manage/download/quiz_assignments/{{quiz_id}}/">
+<a href="{{URL_ROOT}}/exam/manage/download/quiz_assignments/{{quiz_id}}/{{course_id}}">
Download All Assignments</a>
{% endif %}
@@ -194,7 +194,7 @@ Status : <b style="color: red;"> Failed </b><br/>
<h5>Student answer: </h5>
{% if question.type == "upload" %}
{% if has_user_assignments %}
- <a href="{{URL_ROOT}}/exam/manage/download/user_assignment/{{question.id}}/{{data.user.id}}/{{paper.question_paper.quiz.id}}">
+ <a href="{{URL_ROOT}}/exam/manage/download/user_assignment/{{question.id}}/{{data.user.id}}/{{paper.question_paper.quiz.id}}/{{course_id}}">
<div class="panel">
Assignment File for {{ data.user.get_full_name.title }}
</div>
diff --git a/yaksh/templates/yaksh/view_answerpaper.html b/yaksh/templates/yaksh/view_answerpaper.html
index 7cbec91..8f3fad7 100644
--- a/yaksh/templates/yaksh/view_answerpaper.html
+++ b/yaksh/templates/yaksh/view_answerpaper.html
@@ -124,7 +124,7 @@
{% endfor %}
</div>
{% elif question.type == "upload" and has_user_assignment %}
- <a href="{{URL_ROOT}}/exam/download/user_assignment/{{question.id}}/{{data.user.id}}/{{paper.question_paper.quiz.id}}">
+ <a href="{{URL_ROOT}}/exam/download/user_assignment/{{question.id}}/{{data.user.id}}/{{paper.question_paper.quiz.id}}/{{course_id}}">
<div class="well well-sm">
<div class="panel">
Assignment File for {{ data.user.get_full_name.title }}
diff --git a/yaksh/test_models.py b/yaksh/test_models.py
index e0235fe..c9cb953 100644
--- a/yaksh/test_models.py
+++ b/yaksh/test_models.py
@@ -4,7 +4,7 @@ from yaksh.models import User, Profile, Question, Quiz, QuestionPaper,\
QuestionSet, AnswerPaper, Answer, Course, StandardTestCase,\
StdIOBasedTestCase, FileUpload, McqTestCase, AssignmentUpload,\
LearningModule, LearningUnit, Lesson, LessonFile, CourseStatus, \
- TestCaseOrder, create_group
+ create_group
from yaksh.code_server import (
ServerPool, get_result as get_result_from_code_server
)
@@ -25,7 +25,7 @@ from yaksh import settings
def setUpModule():
- mod_group = Group.objects.create(name='moderator')
+ Group.objects.create(name='moderator')
# create user profile
user = User.objects.create_user(username='creator',
@@ -125,6 +125,7 @@ class GlobalMethodsTestCases(unittest.TestCase):
Group.objects.get(name='moderator')
)
+
###############################################################################
class LessonTestCases(unittest.TestCase):
def setUp(self):
@@ -1903,7 +1904,7 @@ class AssignmentUploadTestCases(unittest.TestCase):
self.user2.last_name = "user3"
self.user2.save()
self.quiz = Quiz.objects.get(description="demo quiz 1")
-
+ self.course = Course.objects.get(name="Python Course")
self.questionpaper = QuestionPaper.objects.create(
quiz=self.quiz, total_marks=0.0, shuffle_questions=True
)
@@ -1919,17 +1920,19 @@ class AssignmentUploadTestCases(unittest.TestCase):
file_path2 = os.path.join(tempfile.gettempdir(), "upload2.txt")
self.assignment1 = AssignmentUpload.objects.create(
user=self.user1, assignmentQuestion=self.question,
- assignmentFile=file_path1, question_paper=self.questionpaper
+ assignmentFile=file_path1, question_paper=self.questionpaper,
+ course=self.course
)
self.assignment2 = AssignmentUpload.objects.create(
user=self.user2, assignmentQuestion=self.question,
- assignmentFile=file_path2, question_paper=self.questionpaper
+ assignmentFile=file_path2, question_paper=self.questionpaper,
+ course=self.course
)
def test_get_assignments_for_user_files(self):
assignment_files, file_name = AssignmentUpload.objects.get_assignments(
self.questionpaper, self.question.id,
- self.user1.id
+ self.user1.id, self.course.id
)
self.assertIn("upload1.txt", assignment_files[0].assignmentFile.name)
self.assertEqual(assignment_files[0].user, self.user1)
@@ -1939,15 +1942,15 @@ class AssignmentUploadTestCases(unittest.TestCase):
def test_get_assignments_for_quiz_files(self):
assignment_files, file_name = AssignmentUpload.objects.get_assignments(
- self.questionpaper
- )
+ self.questionpaper, course_id=self.course.id
+ )
files = [os.path.basename(file.assignmentFile.name)
for file in assignment_files]
question_papers = [file.question_paper for file in assignment_files]
self.assertIn("upload1.txt", files)
self.assertIn("upload2.txt", files)
self.assertEqual(question_papers[0].quiz, self.questionpaper.quiz)
- actual_file_name = self.quiz.description.replace(" ", "_")
+ actual_file_name = self.course.name.replace(" ", "_")
file_name = file_name.replace(" ", "_")
self.assertIn(actual_file_name, file_name)
diff --git a/yaksh/urls.py b/yaksh/urls.py
index 8f3401b..8397017 100644
--- a/yaksh/urls.py
+++ b/yaksh/urls.py
@@ -8,7 +8,8 @@ urlpatterns = [
url(r'^update_email/$', views.update_email, name="update_email"),
url(r'^activate/(?P<key>.+)$', views.activate_user, name="activate"),
url(r'^new_activation/$', views.new_activation, name='new_activation'),
- url(r'^toggle_moderator/$', views.toggle_moderator_role, name='toggle_moderator'),
+ url(r'^toggle_moderator/$', views.toggle_moderator_role,
+ name='toggle_moderator'),
url(r'^quizzes/$', views.quizlist_user, name='quizlist_user'),
url(r'^quizzes/(?P<enrolled>\w+)/$', views.quizlist_user,
name='quizlist_user'),
@@ -41,6 +42,9 @@ urlpatterns = [
name='self_enroll'),
url(r'^view_answerpaper/(?P<questionpaper_id>\d+)/(?P<course_id>\d+)$',
views.view_answerpaper, name='view_answerpaper'),
+ url(r'^download/user_assignment/(?P<question_id>\d+)/(?P<user_id>\d+)/'
+ '(?P<quiz_id>\d+)/(?P<course_id>\d+)$',
+ views.download_assignment_file, name="download_user_assignment"),
url(r'^show_lesson/(?P<lesson_id>\d+)/(?P<module_id>\d+)/'
'(?P<course_id>\d+)/$', views.show_lesson, name='show_lesson'),
url(r'^quizzes/view_module/(?P<module_id>\d+)/(?P<course_id>\d+)/$',
@@ -160,10 +164,11 @@ urlpatterns = [
url(r'^manage/courses/download_course_csv/(?P<course_id>\d+)/$',
views.download_course_csv, name="download_course_csv"),
url(r'^manage/download/user_assignment/(?P<question_id>\d+)/'
- '(?P<user_id>\d+)/(?P<quiz_id>\d+)/$',
+ '(?P<user_id>\d+)/(?P<quiz_id>\d+)/(?P<course_id>\d+)$',
views.download_assignment_file, name="download_user_assignment"),
- url(r'^manage/download/quiz_assignments/(?P<quiz_id>\d+)/$',
- views.download_assignment_file, name="download_quiz_assignment"),
+ url(r'^manage/download/quiz_assignments/(?P<quiz_id>\d+)/'
+ '(?P<course_id>\d+)$', views.download_assignment_file,
+ name="download_quiz_assignment"),
url(r'^manage/courses/download_yaml_template/',
views.download_yaml_template, name="download_yaml_template"),
url(r'^manage/download_sample_csv/',
diff --git a/yaksh/views.py b/yaksh/views.py
index ecd7efd..8ccc12b 100644
--- a/yaksh/views.py
+++ b/yaksh/views.py
@@ -30,8 +30,8 @@ from yaksh.code_server import get_result as get_result_from_code_server
from yaksh.models import (
Answer, AnswerPaper, AssignmentUpload, Course, FileUpload, Profile,
QuestionPaper, QuestionSet, Quiz, Question, TestCase, User,
- FIXTURES_DIR_PATH, MOD_GROUP_NAME, Lesson, LessonFile, LearningUnit, LearningModule,
- CourseStatus
+ FIXTURES_DIR_PATH, MOD_GROUP_NAME, Lesson, LessonFile, LearningUnit,
+ LearningModule, CourseStatus
)
from yaksh.forms import (
UserRegisterForm, UserLoginForm, QuizForm, QuestionForm,
@@ -77,7 +77,7 @@ def is_moderator(user, group_name=MOD_GROUP_NAME):
def add_as_moderator(users, group_name=MOD_GROUP_NAME):
""" add users to moderator group """
try:
- group = Group.objects.get(name=group_name)
+ Group.objects.get(name=group_name)
except Group.DoesNotExist:
raise Http404('The Group {0} does not exist.'.format(group_name))
for user in users:
@@ -729,19 +729,17 @@ def check(request, q_id, attempt_num=None, questionpaper_id=None,
for fname in assignment_filename:
fname._name = fname._name.replace(" ", "_")
assignment_files = AssignmentUpload.objects.filter(
- assignmentQuestion=current_question,
- assignmentFile__icontains=fname, user=user,
- question_paper=questionpaper_id)
+ assignmentQuestion=current_question, course_id=course_id,
+ assignmentFile__icontains=fname, user=user,
+ question_paper=questionpaper_id)
if assignment_files.exists():
- assign_file = assignment_files.get(
- assignmentQuestion=current_question,
- assignmentFile__icontains=fname, user=user,
- question_paper=questionpaper_id)
+ assign_file = assignment_files.first()
if os.path.exists(assign_file.assignmentFile.path):
os.remove(assign_file.assignmentFile.path)
assign_file.delete()
AssignmentUpload.objects.create(
user=user, assignmentQuestion=current_question,
+ course_id=course_id,
assignmentFile=fname, question_paper_id=questionpaper_id
)
user_answer = 'ASSIGNMENT UPLOADED'
@@ -1890,10 +1888,10 @@ def view_answerpaper(request, questionpaper_id, course_id):
data = AnswerPaper.objects.get_user_data(user, questionpaper_id,
course_id)
has_user_assignment = AssignmentUpload.objects.filter(
- user=user,
+ user=user, course_id=course.id,
question_paper_id=questionpaper_id
).exists()
- context = {'data': data, 'quiz': quiz,
+ context = {'data': data, 'quiz': quiz, 'course_id': course.id,
"has_user_assignment": has_user_assignment}
return my_render_to_response(
request, 'yaksh/view_answerpaper.html', context
@@ -2100,13 +2098,18 @@ def update_email(request):
@login_required
@email_verified
-def download_assignment_file(request, quiz_id, question_id=None, user_id=None):
+def download_assignment_file(request, quiz_id, course_id,
+ question_id=None, user_id=None):
user = request.user
- if not is_moderator(user):
- raise Http404("You are not allowed to view this page")
- qp = QuestionPaper.objects.get(quiz_id=quiz_id)
+ course = get_object_or_404(Course, pk=course_id)
+ if (not course.is_creator(user) and not course.is_teacher(user) and
+ not course.is_student(user)):
+ raise Http404("You are not allowed to download files for {0}".format(
+ course.name)
+ )
+ qp = get_object_or_404(QuestionPaper, quiz_id=quiz_id)
assignment_files, file_name = AssignmentUpload.objects.get_assignments(
- qp, question_id, user_id
+ qp, question_id, user_id, course_id
)
zipfile_name = string_io()
zip_file = zipfile.ZipFile(zipfile_name, "w")
diff --git a/yaksh/test_views.py b/yaksh/test_views.py
index 3520c61..dbd9547 100644
--- a/yaksh/test_views.py
+++ b/yaksh/test_views.py
@@ -948,13 +948,14 @@ class TestDownloadAssignment(TestCase):
# create assignment file
assignment_file1 = SimpleUploadedFile("file1.txt", b"Test")
assignment_file2 = SimpleUploadedFile("file2.txt", b"Test")
- SimpleUploadedFile("file3.txt", b"Test")
self.assignment1 = AssignmentUpload.objects.create(
user=self.student1, assignmentQuestion=self.question,
+ course=self.course,
assignmentFile=assignment_file1, question_paper=self.question_paper
)
self.assignment2 = AssignmentUpload.objects.create(
user=self.student2, assignmentQuestion=self.question,
+ course=self.course,
assignmentFile=assignment_file2, question_paper=self.question_paper
)
@@ -970,23 +971,25 @@ class TestDownloadAssignment(TestCase):
self.learning_module.delete()
self.learning_unit.delete()
self.mod_group.delete()
- dir_name = self.quiz.description.replace(" ", "_")
+ dir_name = self.course.name.replace(" ", "_")
file_path = os.sep.join((settings.MEDIA_ROOT, dir_name))
if os.path.exists(file_path):
shutil.rmtree(file_path)
def test_download_assignment_denies_student(self):
"""
Check download assignment denies student
"""
self.client.login(
username=self.student1.username,
password=self.student1_plaintext_pass
)
- response = self.client.get(reverse('yaksh:download_quiz_assignment',
- kwargs={'quiz_id': self.quiz.id}),
- follow=True
- )
+ response = self.client.get(
+ reverse('yaksh:download_quiz_assignment',
+ kwargs={'quiz_id': self.quiz.id,
+ "course_id": self.course.id}),
+ follow=True
+ )
self.assertEqual(response.status_code, 404)
def test_download_assignment_per_quiz(self):
@@ -997,11 +1000,13 @@ class TestDownloadAssignment(TestCase):
username=self.user.username,
password=self.user_plaintext_pass
)
- response = self.client.get(reverse('yaksh:download_quiz_assignment',
- kwargs={'quiz_id': self.quiz.id}),
- follow=True
- )
- file_name = "{0}_Assignment_files.zip".format(self.quiz.description)
+ response = self.client.get(
+ reverse('yaksh:download_quiz_assignment',
+ kwargs={'quiz_id': self.quiz.id,
+ 'course_id': self.course.id}),
+ follow=True
+ )
+ file_name = "{0}_Assignment_files.zip".format(self.course.name)
file_name = file_name.replace(" ", "_")
self.assertEqual(response.status_code, 200)
self.assertEqual(response.get('Content-Disposition'),
@@ -1026,7 +1031,8 @@ class TestDownloadAssignment(TestCase):
reverse('yaksh:download_user_assignment',
kwargs={'quiz_id': self.quiz.id,
'question_id': self.question.id,
- 'user_id': self.student2.id
+ 'user_id': self.student2.id,
+ 'course_id': self.course.id
}),
follow=True
)
@@ -970,23 +971,25 @@ class TestDownloadAssignment(TestCase):
def test_download_assignment_denies_student(self):
"""
- Check download assignment denies student
+ Check download assignment denies student not enrolled in a course
"""
self.client.login(